@@ -11,21 +11,21 @@
 
 #include "sketcherMinimizerBond.h"
 
-/*class to represent an interaction with protein residues (e.g. h-bond or 
- pi-pi stacking*/
-class  sketcherMinimizerResidueInteraction
+/* class to represent an interaction with protein residues (e.g. h-bond or
+ pi-pi stacking */
+class EXPORT_COORDGEN sketcherMinimizerResidueInteraction
     : public sketcherMinimizerBond
 {
   public:
-    EXPORT_COORDGEN sketcherMinimizerResidueInteraction();
-    EXPORT_COORDGEN virtual ~sketcherMinimizerResidueInteraction();
+    sketcherMinimizerResidueInteraction();
+    virtual ~sketcherMinimizerResidueInteraction();
     virtual bool isResidueInteraction();
 
-    /*get all the atoms involved at the end side of the interaction*/
+    /* get all the atoms involved at the end side of the interaction */
     std::vector<sketcherMinimizerAtom*> getAllEndAtoms();
     std::vector<sketcherMinimizerAtom*> getAllStartAtoms();
 
-    /*get all the atoms involved at the start side of the interaction*/
+    /* get all the atoms involved at the start side of the interaction */
     std::vector<sketcherMinimizerAtom*> m_otherEndAtoms;
     std::vector<sketcherMinimizerAtom*> m_otherStartAtoms;
 };
